#include "builtin.h"
#include "submodule.h"
#include "strbuf.h"

/*
 * Exit non-zero if any of the submodule names given on the command line is
 * invalid. If no names are given, filter stdin to print only valid names
 * (which is primarily intended for testing).
 */
static int check_name(int argc, const char **argv, const char *prefix)
{
	if (argc > 1) {
		while (*++argv) {
			if (check_submodule_name(*argv) < 0)
				return 1;
		}
	} else {
		struct strbuf buf = STRBUF_INIT;
		while (strbuf_getline(&buf, stdin, '\n') != EOF) {
			if (!check_submodule_name(buf.buf))
				printf("%s\n", buf.buf);
		}
		strbuf_release(&buf);
	}
	return 0;
}

int cmd_submodule__helper(int argc, const char **argv, const char *prefix)
{
	if (argc < 2)
		usage("git submodule--helper <command>");
	if (!strcmp(argv[1], "check-name"))
		return check_name(argc - 1, argv + 1, prefix);
	die(_("'%s' is not a valid submodule--helper subcommand"), argv[1]);
}
